@@ -24,14 +24,17 @@
  *                         Søren Sandmann <sandmann@redhat.com>
  */
 
+#include "config.h"
+
 #include <math.h>
 #include <stdlib.h>
 #include <sysexits.h>
 #include <time.h>
 
+#include <glib.h>
 #include <glib/gi18n.h>
 
-#include <gdk/gdkwindow.h>
+#include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 
 #include <gtk/gtk.h>
@@ -54,7 +57,7 @@
 #define FLOATER_MIN_SIZE (16.0)
 #endif
 #ifndef FLOATER_DEFAULT_COUNT
-#define FLOATER_DEFAULT_COUNT (9)
+#define FLOATER_DEFAULT_COUNT (5)
 #endif
 
 #ifndef SMALL_ANGLE
@@ -69,6 +72,36 @@
 #define GAMMA 2.2
 #endif
 
+static gboolean should_show_paths = FALSE;
+static gboolean should_do_rotations = FALSE;
+static gboolean should_print_stats = FALSE;
+static gint max_floater_count = FLOATER_DEFAULT_COUNT;
+static gchar *geometry = NULL;
+static gchar **filenames = NULL;
+
+static GOptionEntry options[] = {
+       {"show-paths", 'p', 0, G_OPTION_ARG_NONE, &should_show_paths,
+            N_("Show paths that images follow"), NULL},
+
+       {"do-rotations", 'r', 0, G_OPTION_ARG_NONE, &should_do_rotations,
+            N_("Occasionally rotate images as they move"), NULL},
+
+       {"print-stats", 's', 0, G_OPTION_ARG_NONE, &should_print_stats,
+            N_("Print out frame rate and other statistics"), NULL},
+
+       {"number-of-images", 'n', 0, G_OPTION_ARG_INT, &max_floater_count,
+             N_("The maximum number of images to keep on screen"), N_("MAX_IMAGES")},
+
+       {"geometry", NULL, 0, G_OPTION_ARG_STRING, &geometry,
+             N_("The initial size and position of window"), N_("WIDTHxHEIGHT+X+Y")},
+
+       {G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &filenames,
+            N_("The source image to use"), NULL},
+
+       {NULL}
+};
+
+
 typedef struct _Point Point;
 typedef struct _Path Path;
 typedef struct _Rectangle Rectangle;
@@ -984,10 +1017,14 @@ screen_saver_on_expose_event (ScreenSaver    *screen_saver,
   for (tmp = screen_saver->floaters; tmp != NULL; tmp = tmp->next)
     {
       ScreenSaverFloater *floater;
-#ifdef CULL_FLOATERS
       GdkRectangle rect;
       gint size;
 
+      floater = (ScreenSaverFloater *) tmp->data;
+
+      size = CLAMP ((int) (FLOATER_MAX_SIZE * floater->scale),
+		    FLOATER_MIN_SIZE, FLOATER_MAX_SIZE);
+
       rect.x = (int) (floater->position.x - .5 * G_SQRT2 * size);
       rect.y = (int) (floater->position.y - .5 * G_SQRT2 * size);
       rect.width = G_SQRT2 * size;
@@ -995,9 +1032,6 @@ screen_saver_on_expose_event (ScreenSaver    *screen_saver,
 
       if (!gdk_region_rect_in (event->region, &rect))
         continue;
-#endif
-
-      floater = (ScreenSaverFloater *) tmp->data;
 
       if (!screen_saver_floater_do_draw (screen_saver, floater, context))
         {
@@ -1147,78 +1181,10 @@ main (int   argc,
 
   GError *error;
 
-  static gboolean should_show_paths = FALSE;
-  static gboolean should_do_rotations = FALSE;
-  static gboolean should_print_stats = FALSE;
-  static gint max_floater_count = FLOATER_DEFAULT_COUNT;
-
-  static gchar *geometry = NULL;
-  static gchar **filenames = NULL;
-
-  static GOptionEntry options[] =
-    {
-      {
-        .long_name = "show-paths",
-        .short_name = 'p',
-        .arg = G_OPTION_ARG_NONE,
-        .arg_data = &should_show_paths,
-        .description = N_("show paths that images follow")
-      },
-      {
-        .long_name = "do-rotations",
-        .short_name = 'r',
-        .arg = G_OPTION_ARG_NONE,
-        .arg_data = &should_do_rotations,
-        .description = N_("occasionally rotate images as they move")
-      },
-      {
-        .long_name = "print-stats",
-        .short_name = 's',
-        .arg = G_OPTION_ARG_NONE,
-        .arg_data = &should_print_stats,
-        .description = N_("print out frame rate and other statistics")
-      },
-      {
-        .long_name = "number-of-images",
-        .short_name = 'n',
-        .flags = 0,
-        .arg = G_OPTION_ARG_INT,
-        .arg_data = &max_floater_count,
-        .description = N_("the maximum number of images to keep on screen"),
-        /* translators: this should be translated to be symbolic of a generic
-         * number.  e.g, "the screen saver should keep N images on the screen"
-         */
-        .arg_description = N_("N")
-      },
-      {
-        .long_name = G_OPTION_REMAINING,
-        .short_name = '\0',
-        .arg = G_OPTION_ARG_FILENAME_ARRAY,
-        .arg_data = &filenames,
-        .description = N_("the source image to use")
-      },
-      {
-        .long_name = "geometry",
-        .flags = 0,
-        .arg = G_OPTION_ARG_STRING,
-        .arg_data = &geometry,
-        .description = N_("the initial size and position of window"),
-        /* translators: this is an X geometry spec.  WIDTH, HEIGHT, X, and Y
-         * can be translated, but the 'x' area indicator and '+' offset indicators
-         * need to be untranslated and can't be rearranged.
-         */
-        .arg_description = N_("WIDTHxHEIGHT+X+Y")
-      },
-      { NULL }
-    };
-
   error = NULL;
 
-#ifdef ENABLE_NLS
   bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-#endif
   textdomain (GETTEXT_PACKAGE);
 
   gtk_init_with_args (&argc, &argv,
@@ -1227,11 +1193,7 @@ main (int   argc,
                        */
                       _("image - floats images around the screen"),
                       options, GETTEXT_PACKAGE, &error);
-#else
-  gtk_init_with_args (&argc, &argv,
-                      "image - floats images around the screen",
-                      options, NULL, &error);
-#endif
+
 
   if (error != NULL)
     {
